@@ -58,7 +58,7 @@ sub _build_server_cfg {
         return {};
     }
     else {
-        return P->hash->merge( $self->cfg->{PSGI}->{SERVER}, $ARGV{opt} );
+        return P->hash->merge( $self->cfg->{PSGI}->{SERVER}, $ENV->cli->{opt} );
     }
 }
 
